from django.contrib.humanize.templatetags import humanize

from rest_framework import serializers

from coreplus.reactions.api.v1.serializers import ReactionableModelSerializer

from ...models import Discuss


class DiscussSerializerRelation(serializers.ModelSerializer):
    class Meta:
        model = Discuss
        fields = "__all__"


class DiscussSerializer(ReactionableModelSerializer, serializers.ModelSerializer):
    parent = DiscussSerializerRelation(many=False)
    children = DiscussSerializerRelation(many=True)
    humanize_time = serializers.SerializerMethodField(required=False)

    class Meta:
        model = Discuss
        fields = "__all__"

    def get_humanize_time(self, obj):
        return humanize.naturaltime(obj.created)


class DiscussCreateSerializer(serializers.ModelSerializer):
    """
    serializer to create a new discuss
    """

    class Meta:
        model = Discuss
        fields = ["content"]
